==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/mk.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можам да впишувам во \"config\" директориумот!",
    "See %s" : "Види %s",
    "Sample configuration detected" : "Детектирана е едноставна конфигурација",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Education Edition" : "Едукативно издание",
    "Enterprise bundle" : "Професионален пакет",
    "Groupware bundle" : "Пакет со групни производи",
    "Social sharing bundle" : "Пакет за споделување на социјални мрежи",
    "PHP %s or higher is required." : "Потребно е PHP верзија %s или повисока.",
    "PHP with a version lower than %s is required." : "Потебна е PHP верзија пониска од %s.",
    "Following databases are supported: %s" : "Следниве бази со податоци се поддржани: %s",
    "The library %s is not available." : "Библиотеката %s не е достапна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна е библиотека %1$s со повисока верзија од %2$s - достапна верзија %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потебна е библиотека %1$s со пониска верзија од %2$s - достапна верзија %3$s.",
    "Following platforms are supported: %s" : "Следниве платформи се поддржани: %s",
    "Server version %s or higher is required." : "Потребна е верзија %s или поголема на серверот.",
    "Server version %s or lower is required." : "Потербна е верзија %s или помала на серверот.",
    "Logged in user must be an admin or sub admin" : "Најавениот корисник мора да биде администратор или заменик администратор",
    "Logged in user must be an admin" : "Најавениот корисник мора да биде администратор",
    "Authentication" : "Автентикација",
    "Unknown filetype" : "Непознат тип на датотека",
    "Invalid image" : "Невалидна фотографија",
    "today" : "денес",
    "tomorrow" : "утре",
    "yesterday" : "вчера",
    "_in %n day_::_in %n days_" : ["за 1 ден","за %n дена"],
    "_%n day ago_::_%n days ago_" : ["пред 1 ден","пред %n дена"],
    "next month" : "следниот месец",
    "last month" : "предходниот месец",
    "_in %n month_::_in %n months_" : ["за 1 месец","за %n месеца"],
    "_%n month ago_::_%n months ago_" : ["пред 1 месец","пред %n месеци"],
    "next year" : "следниот месец",
    "last year" : "предходната година",
    "_in %n year_::_in %n years_" : ["за 1 година","за %n години"],
    "_%n year ago_::_%n years ago_" : ["пред 1 година","пред %n години"],
    "_in %n hour_::_in %n hours_" : ["за 1 час","за %n часа"],
    "_%n hour ago_::_%n hours ago_" : ["пред 1 час","пред %n часа"],
    "_in %n minute_::_in %n minutes_" : ["за 1 минута","за %n минути"],
    "_%n minute ago_::_%n minutes ago_" : ["пред 1 минута","пред %n минути"],
    "in a few seconds" : "за неколку секунди",
    "seconds ago" : "пред неколку секунди",
    "Empty file" : "Празна датотека",
    "File name is too long" : "Името на датотеката е премногу долго",
    "Empty filename is not allowed" : "Датотеки без име не се дозболени",
    "__language_name__" : "Македонски",
    "This is an automatically sent email, please do not reply." : "Ова е автоматски испратена порака, не одговарајте на истата.",
    "Help" : "Помош",
    "Apps" : "Аппликации",
    "Settings" : "Параметри",
    "Log out" : "Одјава",
    "Users" : "Корисници",
    "Unknown user" : "Непознат корисник",
    "Overview" : "Преглед",
    "Basic settings" : "Основни параметри",
    "Sharing" : "Споделување",
    "Security" : "Безбедност",
    "Groupware" : "Групни производи",
    "Additional settings" : "Дополнителни параметри",
    "Personal info" : "Лични податоци",
    "Mobile & desktop" : "Мобилен & компјутер",
    "%s enter the database username and name." : "%s внесете го корисничкото име и името на базата.",
    "%s enter the database username." : "%s внеси го корисничкото име за базата.",
    "%s enter the database name." : "%s внеси го името на базата.",
    "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
    "Set an admin username." : "Постави администраторско корисничко име",
    "Set an admin password." : "Постави администраторска лозинка.",
    "Can't create or write into the data directory %s" : "Неможете да креирате или да запишувате во оваа папка %s",
    "Invalid Federated Cloud ID" : "Невалиден федерален ID",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s сподели »%2$s« со вас и сака да додаде:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s сподели »%2$s« со вас и сака да додаде",
    "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
    "Open »%s«" : "Отвори »%s«",
    "%1$s via %2$s" : "%1$s преку %2$s",
    "You are not allowed to share %s" : "Не сте овластени да ја споделите %s",
    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
    "The requested share does not exist anymore" : "Споделувањето не постои повеќе",
    "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
    "Sunday" : "Недела",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четврток",
    "Friday" : "Петок",
    "Saturday" : "Сабота",
    "Sun." : "Нед.",
    "Mon." : "Пон.",
    "Tue." : "Вто.",
    "Wed." : "Сре.",
    "Thu." : "Чет.",
    "Fri." : "Пет.",
    "Sat." : "Саб.",
    "Su" : "Не",
    "Mo" : "По",
    "Tu" : "Вт",
    "We" : "Ср",
    "Th" : "Че",
    "Fr" : "Пе",
    "Sa" : "Са",
    "January" : "Јануари",
    "February" : "Февруари",
    "March" : "Март",
    "April" : "Април",
    "May" : "Мај",
    "June" : "Јуни",
    "July" : "Јули",
    "August" : "Август",
    "September" : "Септември",
    "October" : "Октомври",
    "November" : "Ноември",
    "December" : "Декември",
    "Jan." : "Јан.",
    "Feb." : "Фев.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Мај.",
    "Jun." : "Јун.",
    "Jul." : "Јул.",
    "Aug." : "Авг.",
    "Sep." : "Сеп.",
    "Oct." : "Окт.",
    "Nov." : "Ное.",
    "Dec." : "Дек.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Само следниве карактери се дозволени во корисничкото име:: \"a-z\", \"A-Z\", \"0-9\", и \"_.@-'\"",
    "A valid username must be provided" : "Мора да се внесе валидно корисничко име ",
    "Username contains whitespace at the beginning or at the end" : "Корисничкото име содржи празно место на почетокот или на крајот",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "The username is already being used" : "Корисничкото име е веќе во употреба",
    "User disabled" : "Оневозможен корисник",
    "a safe home for all your data" : "безбеден дом за сите ваши податоци",
    "Can't read file" : "Неможе да се прочита датотеката",
    "Application is not enabled" : "Апликацијата не е овозможена",
    "Authentication error" : "Грешка во автентикација",
    "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
    "Setting locale to %s failed" : "Неуспешно поставување на локацијата %s ",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставката \"%s\" не е поставена до \"%s\".",
    "Please ask your server administrator to restart the web server." : "Замолете го сервер администраторот да го рестартира веб серверот.",
    "PostgreSQL >= 9 required" : "Потребно е PostgreSQL >= 9 ",
    "Storage is temporarily not available" : "Складиштето моментално не е достапно",
    "Create" : "Креирај",
    "Change" : "Измени",
    "Delete" : "Избриши",
    "Share" : "Сподели",
    "Unlimited" : "Неограничено",
    "Verifying" : "Потврдување",
    "Verifying …" : "Потврдување …",
    "Verify" : "Потврди",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Споделувањето на %1$s е неуспешно, бидејќи истото веќе е споделено со %2$s",
    "Not allowed to create a federated share with the same user" : "Не е овозможено да креирате федерално споделување со ист корисник",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Споделувањето на %1$s е неуспешно, неможе да се пронајде %2$s, можеби серверот моментално не е достапен.",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Споделувањето на %1$s е неуспешно, бидејќи серверот на %2$s неможе да го пронајде споделувањето"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/mk.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не може да зе запишува во \"config\" директориумот!",
    "See %s" : "Види %s",
    "Sample configuration detected" : "Детектирана е едноставна конфигурација",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Education Edition" : "Едукативно издание",
    "Enterprise bundle" : "Професионален пакет",
    "Groupware bundle" : "Пакет со групни производи",
    "Social sharing bundle" : "Пакет за споделување на социјални мрежи",
    "PHP %s or higher is required." : "Потребно е PHP верзија %s или повисока.",
    "PHP with a version lower than %s is required." : "Потебна е PHP верзија пониска од %s.",
    "Following databases are supported: %s" : "Следниве бази со податоци се поддржани: %s",
    "The library %s is not available." : "Библиотеката %s не е достапна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна е библиотека %1$s со повисока верзија од %2$s - достапна верзија %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потебна е библиотека %1$s со пониска верзија од %2$s - достапна верзија %3$s.",
    "Following platforms are supported: %s" : "Следниве платформи се поддржани: %s",
    "Server version %s or higher is required." : "Потребна е верзија %s или поголема на серверот.",
    "Server version %s or lower is required." : "Потербна е верзија %s или помала на серверот.",
    "Logged in user must be an admin or sub admin" : "Најавениот корисник мора да биде администратор или заменик администратор",
    "Logged in user must be an admin" : "Најавениот корисник мора да биде администратор",
    "Authentication" : "Автентикација",
    "Unknown filetype" : "Непознат тип на датотека",
    "Invalid image" : "Невалидна фотографија",
    "today" : "денес",
    "tomorrow" : "утре",
    "yesterday" : "вчера",
    "_in %n day_::_in %n days_" : ["за 1 ден","за %n дена"],
    "_%n day ago_::_%n days ago_" : ["пред 1 ден","пред %n дена"],
    "next month" : "следниот месец",
    "last month" : "предходниот месец",
    "_in %n month_::_in %n months_" : ["за 1 месец","за %n месеца"],
    "_%n month ago_::_%n months ago_" : ["пред 1 месец","пред %n месеци"],
    "next year" : "следниот месец",
    "last year" : "предходната година",
    "_in %n year_::_in %n years_" : ["за 1 година","за %n години"],
    "_%n year ago_::_%n years ago_" : ["пред 1 година","пред %n години"],
    "_in %n hour_::_in %n hours_" : ["за 1 час","за %n часа"],
    "_%n hour ago_::_%n hours ago_" : ["пред 1 час","пред %n часа"],
    "_in %n minute_::_in %n minutes_" : ["за 1 минута","за %n минути"],
    "_%n minute ago_::_%n minutes ago_" : ["пред 1 минута","пред %n минути"],
    "in a few seconds" : "за неколку секунди",
    "seconds ago" : "пред неколку секунди",
    "Empty file" : "Празна датотека",
    "File name is a reserved word" : "Името на датотеката е резервиран збор",
    "File name contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
    "File name is too long" : "Името на датотеката е премногу долго",
    "Empty filename is not allowed" : "Датотеки без име не се дозболени",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Апликацијата \"%s\" неможе да се инсталира бидејќи не е компатибилна со верзијата на серверот.",
    "__language_name__" : "Македонски",
    "This is an automatically sent email, please do not reply." : "Ова е автоматски испратена порака, не одговарајте на истата.",
    "Help" : "Помош",
    "Apps" : "Аппликации",
    "Settings" : "Параметри",
    "Log out" : "Одјава",
    "Users" : "Корисници",
    "Unknown user" : "Непознат корисник",
    "Additional settings" : "Дополнителни параметри",
    "%s enter the database username and name." : "%s внесете го корисничкото име и името на базата.",
    "%s enter the database username." : "%s внеси го корисничкото име за базата.",
    "%s enter the database name." : "%s внеси го името на базата.",
    "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
    "Set an admin username." : "Постави администраторско корисничко име",
    "Set an admin password." : "Постави администраторска лозинка.",
    "Can't create or write into the data directory %s" : "Неможете да креирате или да запишувате во оваа папка %s",
    "Invalid Federated Cloud ID" : "Невалиден федерален ID",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s сподели »%2$s« со вас и сака да додаде:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s сподели »%2$s« со вас и сака да додаде",
    "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
    "Open »%s«" : "Отвори »%s«",
    "%1$s via %2$s" : "%1$s преку %2$s",
    "You are not allowed to share %s" : "Не сте овластени да ја споделите %s",
    "Expiration date is in the past" : "Рокот на траење е во минато време",
    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
    "The requested share does not exist anymore" : "Споделувањето не постои повеќе",
    "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
    "Sunday" : "Недела",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четврток",
    "Friday" : "Петок",
    "Saturday" : "Сабота",
    "Sun." : "Нед.",
    "Mon." : "Пон.",
    "Tue." : "Вто.",
    "Wed." : "Сре.",
    "Thu." : "Чет.",
    "Fri." : "Пет.",
    "Sat." : "Саб.",
    "Su" : "Не",
    "Mo" : "По",
    "Tu" : "Вт",
    "We" : "Ср",
    "Th" : "Че",
    "Fr" : "Пе",
    "Sa" : "Са",
    "January" : "Јануари",
    "February" : "Февруари",
    "March" : "Март",
    "April" : "Април",
    "May" : "Мај",
    "June" : "Јуни",
    "July" : "Јули",
    "August" : "Август",
    "September" : "Септември",
    "October" : "Октомври",
    "November" : "Ноември",
    "December" : "Декември",
    "Jan." : "Јан.",
    "Feb." : "Фев.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Мај.",
    "Jun." : "Јун.",
    "Jul." : "Јул.",
    "Aug." : "Авг.",
    "Sep." : "Сеп.",
    "Oct." : "Окт.",
    "Nov." : "Ное.",
    "Dec." : "Дек.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Само следниве карактери се дозволени во корисничкото име:: \"a-z\", \"A-Z\", \"0-9\", и \"_.@-'\"",
    "A valid username must be provided" : "Мора да се внесе валидно корисничко име ",
    "Username contains whitespace at the beginning or at the end" : "Корисничкото име содржи празно место на почетокот или на крајот",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "The username is already being used" : "Корисничкото име е веќе во употреба",
    "User disabled" : "Оневозможен корисник",
    "a safe home for all your data" : "безбеден дом за сите ваши податоци",
    "File is currently busy, please try again later" : "Датотеката моментално е зафатена, обидете се повторно",
    "Can't read file" : "Неможе да се прочита датотеката",
    "Application is not enabled" : "Апликацијата не е овозможена",
    "Authentication error" : "Грешка во автентикација",
    "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
    "Cannot write into \"config\" directory" : "Не може да зе запишува во \"config\" директориумот",
    "Cannot write into \"apps\" directory" : "Не може да зе запишува во \"apps\" директориумот",
    "Setting locale to %s failed" : "Неуспешно поставување на локацијата %s ",
    "Please ask your server administrator to install the module." : "Замолете го сервер администраторот да го инсталира додатокот.",
    "PHP module %s not installed." : "PHP модулот %s не е инсталиран.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставката \"%s\" не е поставена до \"%s\".",
    "Please ask your server administrator to restart the web server." : "Замолете го сервер администраторот да го рестартира веб серверот.",
    "PostgreSQL >= 9 required" : "Потребно е PostgreSQL >= 9 ",
    "Please upgrade your database version" : "Ве молиме надградете ја верзијата на базата со податоци",
    "Storage unauthorized. %s" : "Неавторизирано складиште. %s",
    "Storage incomplete configuration. %s" : "Конфигурацијата на складиштето не е комплетна. %s",
    "Storage connection error. %s" : "Грешка во конекција до складиштето. %s",
    "Storage is temporarily not available" : "Складиштето моментално не е достапно",
    "Create" : "Креирај",
    "Change" : "Измени",
    "Delete" : "Избриши",
    "Share" : "Сподели",
    "Overview" : "Преглед",
    "Basic settings" : "Основни параметри",
    "Sharing" : "Споделување",
    "Security" : "Безбедност",
    "Groupware" : "Групни производи",
    "Personal info" : "Лични податоци",
    "Mobile & desktop" : "Мобилен & компјутер",
    "Unlimited" : "Неограничено",
    "Verifying" : "Потврдување",
    "Verifying …" : "Потврдување …",
    "Verify" : "Потврди",
    "Sharing %s failed, because you can not share with yourself" : "Споделувањето на %s е неуспешно, бидејќи неможете да го споделите сами со себе",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Споделувањето на %1$s е неуспешно, бидејќи истото веќе е споделено со %2$s",
    "Not allowed to create a federated share with the same user" : "Не е овозможено да креирате федерално споделување со ист корисник",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Споделувањето на %1$s е неуспешно, неможе да се пронајде %2$s, можеби серверот моментално не е достапен.",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Споделувањето на %1$s е неуспешно, бидејќи серверот на %2$s неможе да го пронајде споделувањето"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
